@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ G_BEGIN_DECLS
 #define MISC_CREATE_MENU_DISABLE   32
 #define MISC_CREATE_MENU_MASK      7
 
+
 typedef struct _MiscCreateMenuEntry
 {
   gchar *path;
@@ -159,13 +160,13 @@ misc_mnemonic_to_text (const gchar *mnemonic);
          page,ページ
           pos,位置                                                          */
 void
-misc_set_scroll_bar (GtkWidget     *scroll,
-                     GtkSignalFunc  func,
-                     gpointer       func_data,
-                     const gint     min,
-                     const gint     max,
-                     const gint     page,
-                     const gint     pos);
+misc_set_scroll_bar (GtkWidget  *scroll,
+                     GCallback   func,
+                     gpointer    func_data,
+                     const gint  min,
+                     const gint  max,
+                     const gint  page,
+                     const gint  pos);
 
 
 /*  ja:Windowの内容をスクロールする
