@@ -1,6 +1,6 @@
 /*
     orzcomm
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #define __ORZ_COMM_H__
 
 
-#include "gcommon.h"
+#include "misc/gcommon.h"
 #ifdef G_OS_WIN32
 # include <windows.h>
 #endif /* G_OS_WIN32 */
