@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -121,7 +121,7 @@ command_open (GtkWidget *widget,
       lpszFilter[pos] = '\0';
       szFile[0] = '\0';
       ofn.lStructSize = sizeof (OPENFILENAMEW);
-      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.hwndOwner = GDK_WINDOW_HWND (gtk_widget_get_window (window));
       ofn.lpstrFilter = lpszFilter;
       for (i = ftnum - 1; i >= 0; i--)
         if (ftype[i].ft_id == findex)
@@ -159,14 +159,7 @@ command_open (GtkWidget *widget,
 
 # if GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE)
       lpszPath = open_path
-#  if GTK_CHECK_VERSION(2,8,0)
-                        ? g_win32_locale_filename_from_utf8 (open_path)
-#  elif GTK_CHECK_VERSION(2,6,0)
-                        ? g_locale_from_utf8 (open_path, -1, NULL, NULL, NULL)
-#  else /* not GTK_CHECK_VERSION(2,6,0) */
-                        ? g_strdup (open_path)
-#  endif /* not GTK_CHECK_VERSION(2,6,0) */
-                        : NULL;
+                        ? g_win32_locale_filename_from_utf8 (open_path) : NULL;
       /* ja:フィルタの設定 */
       for (i = 0; i < ftnum; i++)
         {
@@ -191,7 +184,7 @@ command_open (GtkWidget *widget,
       lpszFilter[pos] = '\0';
       szFile[0] = '\0';
       ofn.lStructSize = sizeof (OPENFILENAMEA);
-      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.hwndOwner = GDK_WINDOW_HWND (gtk_widget_get_window (window));
       ofn.lpstrFilter = lpszFilter;
       for (i = ftnum - 1; i >= 0; i--)
         if (ftype[i].ft_id == findex)
@@ -314,11 +307,7 @@ command_save (GtkWidget *widget,
           gchar *utf8str;
           GtkWidget *dialog;
 
-#if GLIB_CHECK_VERSION(2,6,0)
           utf8str = g_filename_display_name (file);
-#else /* not GLIB_CHECK_VERSION(2,6,0) */
-          utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
-#endif /* not GLIB_CHECK_VERSION(2,6,0) */
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
@@ -403,7 +392,7 @@ command_saveas (GtkWidget *widget,
       lpszFilter[pos] = '\0';
       szFile[0] = '\0';
       ofn.lStructSize = sizeof (OPENFILENAMEW);
-      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.hwndOwner = GDK_WINDOW_HWND (gtk_widget_get_window (window));
       ofn.lpstrFilter = lpszFilter;
       ofn.nFilterIndex = findex - 1;
       ofn.lpstrCustomFilter = NULL;
@@ -438,14 +427,7 @@ command_saveas (GtkWidget *widget,
 
 # if GLIB_CHECK_VERSION(2,6,0) || ! defined (UNICODE)
       lpszPath = save_path
-#  if GTK_CHECK_VERSION(2,8,0)
-                        ? g_win32_locale_filename_from_utf8 (save_path)
-#  elif GTK_CHECK_VERSION(2,6,0)
-                        ? g_locale_from_utf8 (save_path, -1, NULL, NULL, NULL)
-#  else /* not GTK_CHECK_VERSION(2,6,0) */
-                        ? g_strdup (save_path)
-#  endif /* not GTK_CHECK_VERSION(2,6,0) */
-                        : NULL;
+                        ? g_win32_locale_filename_from_utf8 (save_path) : NULL;
       /* ja:フィルタの設定 */
       for (i = 0; i < ftnum; i++)
         {
@@ -470,7 +452,7 @@ command_saveas (GtkWidget *widget,
       lpszFilter[pos] = '\0';
       szFile[0] = '\0';
       ofn.lStructSize = sizeof (OPENFILENAMEA);
-      ofn.hwndOwner = GDK_WINDOW_HWND (window->window);
+      ofn.hwndOwner = GDK_WINDOW_HWND (gtk_widget_get_window (window));
       ofn.lpstrFilter = lpszFilter;
       ofn.nFilterIndex = findex - 1;
       ofn.lpstrCustomFilter = NULL;
@@ -570,11 +552,7 @@ command_saveas (GtkWidget *widget,
           GtkWidget *dialog;
 #endif /* G_OS_WIN32 */
 
-#if GLIB_CHECK_VERSION(2,6,0)
           filename = g_filename_display_name (file);
-#else /* not GLIB_CHECK_VERSION(2,6,0) */
-          filename = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
-#endif /* not GLIB_CHECK_VERSION(2,6,0) */
           dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                     GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
@@ -622,6 +600,9 @@ command_reload (GtkWidget *widget,
             (_("File %s was edited.\nRestore to existed file?"), file) : NULL;
   if (reload_dialog (&tmaid->ft, text))
     {
+      GtkAllocation allocation;
+
+      gtk_widget_get_allocation (tmaid->drawing, &allocation);
       /* ja:バッファを解放する */
       while (tmaid->start->prev)
         tmaid->start = tmaid->start->prev;
@@ -646,13 +627,11 @@ command_reload (GtkWidget *widget,
       misc_set_scroll_bar (tmaid->hscroll,
                 G_CALLBACK (signal_value_changed_hscroll), tmaid,
                 0, edit_get_width_max (tmaid) + 1,
-                MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1),
-                                                                tmaid->top.x);
+                MAX (allocation.width / tmaid->font_width, 1), tmaid->top.x);
       misc_set_scroll_bar (tmaid->vscroll,
             G_CALLBACK (signal_value_changed_vscroll), tmaid,
             0, tmaid->max,
-            MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1),
-                                                                tmaid->top.y);
+            MAX (allocation.height / tmaid->font_height, 1), tmaid->top.y);
       set_menu_bar (tmaid);
       draw_caret (tmaid, NULL);
       gtk_widget_queue_draw (tmaid->drawing);
@@ -747,7 +726,7 @@ command_exit (GtkWidget *widget,
   GdkEvent event;
 
   event.any.type = GDK_DELETE;
-  event.any.window = window->window;
+  event.any.window = gtk_widget_get_window (window);
   event.any.send_event = FALSE;
   gdk_event_put (&event);
 }
@@ -922,14 +901,16 @@ command_all (GtkWidget *widget,
 {
   gint sx, sy;
   GdkPoint top;
+  GtkAllocation allocation;
   TmaidWindow *tmaid;
 
   tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   if (tmaid->max <= 1 && tmaid->start->length <= 0)
     return;
   top = tmaid->top;
-  sx = MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1);
-  sy = MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1);
+  gtk_widget_get_allocation (tmaid->drawing, &allocation);
+  sx = MAX (allocation.width / tmaid->font_width, 1);
+  sy = MAX (allocation.height / tmaid->font_height, 1);
   if (tmaid->select.x < 0)/* ja:新たに選択する */
     gtk_selection_owner_set (window, GDK_SELECTION_PRIMARY, GDK_CURRENT_TIME);
   tmaid->select.x = tmaid->select.y = 0;
@@ -959,7 +940,8 @@ void
 command_find (GtkWidget *widget,
               gpointer   user_data)
 {
-  if (GTK_WIDGET_HAS_FOCUS (find_entry) && !GTK_WIDGET_VISIBLE (replace_combo))
+  if (gtk_widget_has_focus (find_entry)
+                                    && !gtk_widget_get_visible (replace_combo))
     find_box_end ();
   else
     find_box_start ();
@@ -1005,7 +987,7 @@ void
 command_replace (GtkWidget *widget,
                  gpointer   user_data)
 {
-  if (GTK_WIDGET_HAS_FOCUS (replace_entry))
+  if (gtk_widget_has_focus (replace_entry))
     find_box_end ();
   else
     replace_box_start ();
