@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -452,7 +452,7 @@ file_open_edit (const gchar *file)
                             | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
                             | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
                             | GDK_FOCUS_CHANGE_MASK | GDK_SCROLL_MASK);
-  GTK_WIDGET_SET_FLAGS (tmaid->drawing, GTK_CAN_FOCUS);
+  gtk_widget_set_can_focus (tmaid->drawing, TRUE);
   /* ja:フォント */
   if (tmaid->ft.font_name)
     {
@@ -500,7 +500,7 @@ file_open_edit (const gchar *file)
   while (gtk_events_pending ())
     gtk_main_iteration ();
 #ifndef G_OS_WIN32
-  gdk_window_get_origin (tmaid->drawing->window, &x, &y);
+  gdk_window_get_origin (gtk_widget_get_window (tmaid->drawing), &x, &y);
   gtk_window_move (GTK_WINDOW (gtk_widget_get_parent (tmaid->preedit)), x, y);
 #endif /* not G_OS_WIN32 */
   rc.x = rc.y = rc.width = 0;
