@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -277,6 +277,7 @@ find_operation (TmaidWindow    *tmaid,
     {
       gint sx, sy;
       GdkPoint cursor, select, top;
+      GtkAllocation allocation;
 
       cursor = tmaid->cursor;
       select = tmaid->select;
@@ -303,8 +304,9 @@ find_operation (TmaidWindow    *tmaid,
       tmaid->cursor.y = data.y;
       tmaid->select.x = edit_get_screen_pos (tmaid, st.x, st.y);
       tmaid->select.y = st.y;
-      sx = MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1);
-      sy = MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1);
+      gtk_widget_get_allocation (tmaid->drawing, &allocation);
+      sx = MAX (allocation.width / tmaid->font_width, 1);
+      sy = MAX (allocation.height / tmaid->font_height, 1);
       if (tmaid->cursor.x < tmaid->top.x)
         tmaid->top.x = tmaid->cursor.x;
       else if (tmaid->cursor.x - sx + 1 > tmaid->top.x)
