@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 #include "misc/misc.h"
 #ifdef G_OS_WIN32
 # include "orz/orzmdi.h"
+# if GTK_CHECK_VERSION(2,24,0)
+#  include <cairo-win32.h>
+# endif /* GTK_CHECK_VERSION(2,24,0) */
 # include <gdk/gdkwin32.h>
 #else /* not G_OS_WIN32 */
 # include "misc/fileio.h"
@@ -58,17 +61,24 @@ print_out (TmaidWindow *tmaid,
   guchar *c;
   gint i, x, y, sx, sy, data_pos, end_pos, line, width, channels, rowstride;
   LineBuffer *p;
+#if GTK_CHECK_VERSION(2,24,0)
+# ifdef G_OS_WIN32
+  cairo_surface_t *surface;
+# else /* not G_OS_WIN32 */
+  GdkPixmap *pixmap;
+# endif /* not G_OS_WIN32 */
+#else /* not GTK_CHECK_VERSION(2,24,0) */
   GdkGC *gc;
   GdkPixmap *pixmap;
-  GdkPixbuf *pixbuf;
+#endif /* not GTK_CHECK_VERSION(2,24,0) */
   GdkPoint start, end;
 #ifdef G_OS_WIN32
   gchar *name, *utf8str;
-  HBITMAP hBitmap;
   HDC hDC;
   DOCINFO di;
 #else /* not G_OS_WIN32 */
   FILE *fp;
+  GdkPixbuf *pixbuf;
 #endif /* not G_OS_WIN32 */
 
   sx = prncfg->column * prncfg->font_width;
@@ -132,14 +142,8 @@ print_out (TmaidWindow *tmaid,
     }
   g_memset (&di, 0, sizeof (DOCINFO));
   di.cbSize = sizeof (DOCINFO);
-#if GLIB_CHECK_VERSION(2,6,0)
   utf8str = g_filename_display_name (orz_mdi_get_file (ORZ_MDI (mdi),
                         orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid)));
-#else /* not GLIB_CHECK_VERSION(2,6,0) */
-  utf8str = g_filename_to_utf8 (orz_mdi_get_file (ORZ_MDI (mdi),
-                        orz_mdi_get_page_from_data (ORZ_MDI (mdi), tmaid)),
-                                                        -1, NULL, NULL, NULL);
-#endif /* not GLIB_CHECK_VERSION(2,6,0) */
 # ifdef UNICODE
   name = g_utf8_to_utf16 (utf8str, -1, NULL, NULL, NULL);
 # else /* not UNICODE */
@@ -189,7 +193,7 @@ print_out (TmaidWindow *tmaid,
     {
 # endif /* G_OS_UNIX */
       /* ja:ファイル */
-      fp = fopen (prncfg->file, "wt");
+      fp = g_fopen (prncfg->file, "wt");
       if (!fp)
         {
           GtkWidget *dialog;
@@ -208,12 +212,20 @@ print_out (TmaidWindow *tmaid,
     }
 # endif /* G_OS_UNIX */
   fputs ("%!PS-Adobe-3.0\n", fp);
-#endif /* not G_OS_WIN32 */
-  pixmap = gdk_pixmap_new (window->window, sx, sy, -1);
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, sx, sy);
+#endif /* not G_OS_WIN32 */
+#if GTK_CHECK_VERSION(2,24,0)
+# ifdef G_OS_WIN32
+  surface = cairo_win32_surface_create (hDC);
+# else /* not G_OS_WIN32 */
+  pixmap = gdk_pixmap_new (gtk_widget_get_window (window), sx, sy, -1);
+# endif /* not G_OS_WIN32 */
+#else /* not GTK_CHECK_VERSION(2,24,0) */
+  pixmap = gdk_pixmap_new (gtk_widget_get_window (window), sx, sy, -1);
   gc = gdk_gc_new (pixmap);
   gdk_gc_set_line_attributes (gc, 1,
                                 GDK_LINE_SOLID, GDK_CAP_BUTT, GDK_JOIN_MITER);
+#endif /* not GTK_CHECK_VERSION(2,24,0) */
   /* ja:中断ボタン */
   abort_box_start ();
 #if defined (G_OS_UNIX)
@@ -230,11 +242,33 @@ print_out (TmaidWindow *tmaid,
         {
           /* ja:ページスタート */
           /* ja:背景 */
+#if GTK_CHECK_VERSION(2,24,0)
+          cairo_t *cr;
+
+# ifdef G_OS_WIN32
+          cr = cairo_create (surface);
+# else /* not G_OS_WIN32 */
+          cr = gdk_cairo_create (pixmap);
+# endif /* not G_OS_WIN32 */
+          cairo_set_line_width (cr, 1);
+          cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
+          gdk_cairo_set_source_color (cr, (tmaid->ft.syscol
+                                    ? system_color : tmaid->ft.color) + 11);
+          cairo_rectangle (cr, 0, 0, sx, sy);
+          cairo_fill (cr);
+          gdk_cairo_set_source_color (cr, (tmaid->ft.syscol
+                                    ? system_color : tmaid->ft.color) + 10);
+#else /* not GTK_CHECK_VERSION(2,24,0) */
+# ifdef G_OS_WIN32
+          HBITMAP hBitmap;
+# endif /* G_OS_WIN32 */
+
           gdk_gc_set_foreground (gc, (tmaid->ft.syscol
                                     ? system_color : tmaid->ft.color) + 11);
           gdk_draw_rectangle (pixmap, gc, TRUE, 0, 0, sx, sy);
           gdk_gc_set_foreground (gc, (tmaid->ft.syscol
                                     ? system_color : tmaid->ft.color) + 10);
+#endif /* not GTK_CHECK_VERSION(2,24,0) */
           x = y = 0;
           while (y <= sy - tmaid->font_height && line <= end.y)
             {
@@ -275,7 +309,12 @@ print_out (TmaidWindow *tmaid,
                       pango_layout_set_text (tmaid->layout,
                                         p->text + data_pos,
                                         charset_length (p->text[data_pos]));
+#if GTK_CHECK_VERSION(2,24,0)
+                      cairo_move_to (cr, x, y);
+                      pango_cairo_show_layout (cr, tmaid->layout);
+#else /* not GTK_CHECK_VERSION(2,24,0) */
                       gdk_draw_layout (pixmap, gc, x, y, tmaid->layout);
+#endif /* not GTK_CHECK_VERSION(2,24,0) */
                       data_pos += charset_length (p->text[data_pos]);
                     }
                   else
@@ -283,7 +322,12 @@ print_out (TmaidWindow *tmaid,
                       /* ja:強制半角 */
                       pango_layout_set_text (tmaid->layout,
                                                         p->text + data_pos, 1);
+#if GTK_CHECK_VERSION(2,24,0)
+                      cairo_move_to (cr, x, y);
+                      pango_cairo_show_layout (cr, tmaid->layout);
+#else /* not GTK_CHECK_VERSION(2,24,0) */
                       gdk_draw_layout (pixmap, gc, x, y, tmaid->layout);
+#endif /* not GTK_CHECK_VERSION(2,24,0) */
                       data_pos++;
                     }
                   x += width;
@@ -291,13 +335,20 @@ print_out (TmaidWindow *tmaid,
               x = 0;
               y += tmaid->font_height;
             }
+#if GTK_CHECK_VERSION(2,24,0)
+          cairo_destroy (cr);
+#endif /* GTK_CHECK_VERSION(2,24,0) */
 #ifdef G_OS_WIN32
+#if ! GTK_CHECK_VERSION(2,24,0)
           hBitmap = SelectObject (hDC, (HBITMAP)GDK_WINDOW_HWND (pixmap));
+#endif /* not GTK_CHECK_VERSION(2,24,0) */
           if (StartPage (prncfg->pd.hDC) <= 0)
             {
               GtkWidget *dialog;
 
+# if ! GTK_CHECK_VERSION(2,24,0)
               hBitmap = SelectObject (hDC, hBitmap);
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
               /* ja:中断ボタン */
               abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
@@ -316,6 +367,9 @@ print_out (TmaidWindow *tmaid,
               GtkWidget *dialog;
 
               EndPage (prncfg->pd.hDC);
+# if ! GTK_CHECK_VERSION(2,24,0)
+              hBitmap = SelectObject (hDC, hBitmap);
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
               /* ja:中断ボタン */
               abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
@@ -326,14 +380,15 @@ print_out (TmaidWindow *tmaid,
                                     G_CALLBACK (misc_dialog_key_press), NULL);
               gtk_dialog_run (GTK_DIALOG (dialog));
               gtk_widget_destroy (dialog);
-              hBitmap = SelectObject (hDC, hBitmap);
               goto loop;
             }
           if (EndPage (prncfg->pd.hDC) <= 0)
             {
               GtkWidget *dialog;
 
+# if ! GTK_CHECK_VERSION(2,24,0)
               hBitmap = SelectObject (hDC, hBitmap);
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
               /* ja:中断ボタン */
               abort_box_end ();
               dialog = gtk_message_dialog_new (GTK_WINDOW (window),
@@ -346,9 +401,11 @@ print_out (TmaidWindow *tmaid,
               gtk_widget_destroy (dialog);
               goto loop;
             }
+# if ! GTK_CHECK_VERSION(2,24,0)
           hBitmap = SelectObject (hDC, hBitmap);
+# endif /* not GTK_CHECK_VERSION(2,24,0) */
 #else /* not G_OS_WIN32 */
-          fprintf (fp,
+          g_fprintf (fp,
                 "gsave\n"
                 "%d %d translate\n"
                 "%d %d scale\n"
@@ -371,7 +428,7 @@ print_out (TmaidWindow *tmaid,
                 for (y = sy - 1; y >= 0; y--)
                   {
                     for (x = 0; x < sx; x++)
-                      fprintf (fp, "%02x", c[x * channels + y * rowstride]);
+                      g_fprintf (fp, "%02x", c[x * channels + y * rowstride]);
                     fputc ('\n', fp);
                   }
                 break;
@@ -380,7 +437,7 @@ print_out (TmaidWindow *tmaid,
                 for (y = sy - 1;y >= 0; y--)
                   {
                     for (x = 0; x < sx; x++)
-                      fprintf (fp, "%02x",
+                      g_fprintf (fp, "%02x",
                                     (c[x * channels + y * rowstride] * 77
                                     +c[x * channels + y * rowstride + 1] * 150
                                     +c[x * channels + y * rowstride + 2] * 29)
@@ -410,9 +467,16 @@ print_out (TmaidWindow *tmaid,
   abort_box_end ();
   loop:
   /* ja:終了処理 */
-  g_object_unref (gc);
-  g_object_unref (pixbuf);
+#if GTK_CHECK_VERSION(2,24,0)
+# ifdef G_OS_WIN32
+  cairo_surface_destroy (surface);
+# else /* not G_OS_WIN32 */
   g_object_unref (pixmap);
+# endif /* not G_OS_WIN32 */
+#else /* not GTK_CHECK_VERSION(2,24,0) */
+  g_object_unref (gc);
+  g_object_unref (pixmap);
+#endif /* not GTK_CHECK_VERSION(2,24,0) */
 #ifdef G_OS_WIN32
   if (EndDoc (prncfg->pd.hDC) <= 0)
     {
@@ -460,6 +524,7 @@ print_out (TmaidWindow *tmaid,
       return FALSE;
     }
 #else /* not G_OS_WIN32 */
+  g_object_unref (pixbuf);
 # ifdef G_OS_UNIX
   if (prncfg->mode) /* ja:プリンタ */
     pclose (fp);
@@ -840,7 +905,7 @@ print_dialog (PrintConfig *prncfg)
   /* ja:プリンター */
   g_memset (&prncfg->pd, 0, sizeof (PRINTDLG));
   prncfg->pd.lStructSize = sizeof (PRINTDLG);
-  prncfg->pd.hwndOwner = GDK_WINDOW_HWND (window->window);
+  prncfg->pd.hwndOwner = GDK_WINDOW_HWND (gtk_widget_get_window (window));
   prncfg->pd.Flags = PD_HIDEPRINTTOFILE | PD_RETURNDC;
   if (prncfg->select)
     prncfg->pd.Flags |= PD_SELECTION;
@@ -1078,8 +1143,8 @@ print_dialog (PrintConfig *prncfg)
 #endif /* not G_OS_WIN32 */
 
   /* ja:フレームとボックス */
-  vbox = gtk_vbox_new (FALSE, SPACING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
+  vbox = gtk_dialog_get_content_area (GTK_DIALOG (prndlg.dialog));
+  gtk_box_set_spacing (GTK_BOX (vbox), SPACING);
   hbox0 = gtk_hbox_new (FALSE, SPACING);
   hbox1 = gtk_hbox_new (FALSE,0);
   gtk_box_pack_start (GTK_BOX (hbox1), prndlg.spin_column, TRUE, TRUE, 0);
@@ -1123,8 +1188,6 @@ print_dialog (PrintConfig *prncfg)
   gtk_box_pack_start (GTK_BOX (vbox), frame1, FALSE, FALSE, 0);
 #endif /* not G_OS_WIN32 */
 
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (prndlg.dialog)->vbox), vbox);
-
   /* ja:表示 */
   print_dialog_changed_spin (NULL, &prndlg);
   gtk_widget_show_all (vbox);
