@@ -59,7 +59,6 @@ replace_operation (gint mode)
       gint bytes, data_pos;
       TmaidHistory *d;
 
-      replace = TRUE;
       ri.arrow = (tmaid->select.y < tmaid->cursor.y)
                                         || (tmaid->select.y == tmaid->cursor.y
                                         && tmaid->select.x < tmaid->cursor.x);
@@ -69,9 +68,7 @@ replace_operation (gint mode)
           ri.src = g_malloc (bytes + 1);
           edit_cpy_sel_mem (tmaid, &tmaid->select, &tmaid->cursor, ri.src);
           ri.src[bytes] = '\0';
-          ri.start = tmaid->select;
-          ri.end = tmaid->cursor;
-          mode = repinfo_dialog (&ri);
+          mode = repinfo_run (&ri);
           g_free (ri.src);
           if (mode == REPLACE_CANCEL || mode == REPLACE_NEXT)
             continue;
@@ -88,12 +85,13 @@ replace_operation (gint mode)
         count++;
       d->next = tmaid->undo;
       tmaid->undo = d;
+      replace = TRUE;
     }
+  gtk_widget_hide (repinfo_box);
   /* ja:中断ボタン */
   abort_box_end ();
   if (replace)
     {
-      orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
       if (mode == REPLACE_ALL)
         {
           GtkWidget *dialog;
@@ -107,6 +105,9 @@ replace_operation (gint mode)
           gtk_dialog_run (GTK_DIALOG (dialog));
           gtk_widget_destroy (dialog);
         }
+      orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
+      set_menu_bar (tmaid);
+      gtk_widget_grab_focus (tmaid->drawing);
     }
   else
     {
@@ -121,5 +122,4 @@ replace_operation (gint mode)
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
     }
-  set_menu_bar (tmaid);
 }
